#  Licensed to Elasticsearch B.V. under one or more contributor
#  license agreements. See the NOTICE file distributed with
#  this work for additional information regarding copyright
#  ownership. Elasticsearch B.V. licenses this file to you under
#  the Apache License, Version 2.0 (the "License"); you may
#  not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
# 	http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing,
#  software distributed under the License is distributed on an
#  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
#  KIND, either express or implied.  See the License for the
#  specific language governing permissions and limitations
#  under the License.

import pytest

from elasticsearch import AsyncElasticsearch

from ..async_examples.completion import Person


@pytest.mark.anyio
async def test_person_suggests_on_all_variants_of_name(
    async_write_client: AsyncElasticsearch,
) -> None:
    await Person.init(using=async_write_client)

    await Person(_id=None, name="Honza Král", popularity=42).save(refresh=True)

    s = Person.search().suggest("t", "kra", completion={"field": "suggest"})
    response = await s.execute()

    opts = response.suggest["t"][0].options

    assert 1 == len(opts)
    assert opts[0]._score == 42
    assert opts[0]._source.name == "Honza Král"
